==> idem-aiohttp-2.1.2.tar.gz: idem-aiohttp-2.1.2/idem_aiohttp/exec/request/raw.py <==
from typing import List


async def delete(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.delete(
        ctx, url=url, **kwargs
    ) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "comment": response.reason,
            "headers": response.headers,
        }


async def get(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.get(ctx, url=url, **kwargs) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "comment": response.reason,
            "headers": response.headers,
        }


async def patch(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.patch(ctx, url=url, **kwargs) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "comment": response.reason,
            "headers": response.headers,
        }


async def post(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.post(ctx, url=url, **kwargs) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "comment": response.reason,
            "headers": response.headers,
        }


async def put(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.put(ctx, url=url, **kwargs) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "comment": response.reason,
            "headers": response.headers,
        }

==> idem-aiohttp-2.1.3.tar.gz: idem-aiohttp-2.1.3/idem_aiohttp/exec/request/raw.py <==
from typing import List


async def delete(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.delete(
        ctx, url=url, **kwargs
    ) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "status_code": response.status,
            "comment": response.reason,
            "headers": response.headers,
        }


async def get(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.get(ctx, url=url, **kwargs) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "status_code": response.status,
            "comment": response.reason,
            "headers": response.headers,
        }


async def patch(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.patch(ctx, url=url, **kwargs) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "status_code": response.status,
            "comment": response.reason,
            "headers": response.headers,
        }


async def post(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.post(ctx, url=url, **kwargs) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "status_code": response.status,
            "comment": response.reason,
            "headers": response.headers,
        }


async def put(hub, ctx, url: str, success_codes: List[int] = None, **kwargs):
    if not success_codes:
        success_codes = [200]
    async with await hub.tool.request.session.put(ctx, url=url, **kwargs) as response:
        return {
            "ret": await response.read(),
            "status": response.status in success_codes,
            "status_code": response.status,
            "comment": response.reason,
            "headers": response.headers,
        }
